@@ -56,14 +56,18 @@
 #' (unless set explicitly in \code{priors}). Defaults to a no effect
 #' \code{prior("spike",  parameters = list(location = 0))}.
 #' @param standardize_predictors whether continuous predictors should be standardized prior to
-#' estimating the model. Defaults to \code{TRUE}.
+#' estimating the model. Defaults to \code{TRUE}. Continuous predictor standardization is important
+#' for applying the default prior distributions for continuous predictors. Note that the resulting
+#' output corresponds to standardized meta-regression coefficients.
 #' @inheritParams RoBMA
 #' @inheritParams combine_data
 #'
 #' @details The \href{../doc/MetaRegression.html}{\code{vignette("/MetaRegression", package = "RoBMA")}}
 #' vignette describes how to use [RoBMA.reg()] function to fit Bayesian meta-regression ensembles. See
 #' \insertCite{bartos2023robust;textual}{RoBMA} for more details about the methodology and
-#' [RoBMA()] for more details about the function options.
+#' [RoBMA()] for more details about the function options. By default, the function standardizes
+#' continuous predictors. As such, the output should be interpreted as standardized meta-regression
+#' coefficients.
 #'
 #' The RoBMA.reg function first generates models from a combination of the
 #' provided priors for each of the model parameters. Then, the individual models
@@ -113,34 +117,24 @@ RoBMA.reg <- function(
     effect_direction       = "positive",
 
     # prior specification
-    priors       = NULL,
-    model_type   = NULL,
+    priors = NULL, model_type = NULL, rescale_priors = 1,
 
-    priors_effect         = prior(distribution = "normal",    parameters = list(mean  = 0, sd = 1)),
-    priors_heterogeneity  = prior(distribution = "invgamma",  parameters = list(shape = 1, scale = .15)),
-    priors_bias           = list(
-      prior_weightfunction(distribution = "two.sided", parameters = list(alpha = c(1, 1),       steps = c(0.05)),             prior_weights = 1/12),
-      prior_weightfunction(distribution = "two.sided", parameters = list(alpha = c(1, 1, 1),    steps = c(0.05, 0.10)),       prior_weights = 1/12),
-      prior_weightfunction(distribution = "one.sided", parameters = list(alpha = c(1, 1),       steps = c(0.05)),             prior_weights = 1/12),
-      prior_weightfunction(distribution = "one.sided", parameters = list(alpha = c(1, 1, 1),    steps = c(0.025, 0.05)),      prior_weights = 1/12),
-      prior_weightfunction(distribution = "one.sided", parameters = list(alpha = c(1, 1, 1),    steps = c(0.05, 0.5)),        prior_weights = 1/12),
-      prior_weightfunction(distribution = "one.sided", parameters = list(alpha = c(1, 1, 1, 1), steps = c(0.025, 0.05, 0.5)), prior_weights = 1/12),
-      prior_PET(distribution   = "Cauchy", parameters = list(0,1), truncation = list(0, Inf),  prior_weights = 1/4),
-      prior_PEESE(distribution = "Cauchy", parameters = list(0,5), truncation = list(0, Inf),  prior_weights = 1/4)
-    ),
-    priors_effect_null         = prior(distribution = "point", parameters = list(location = 0)),
-    priors_heterogeneity_null  = prior(distribution = "point", parameters = list(location = 0)),
-    priors_bias_null           = prior_none(),
-    priors_hierarchical        = prior("beta", parameters = list(alpha = 1, beta = 1)),
-    priors_hierarchical_null   = NULL,
+    priors_effect              = set_default_priors("effect",        rescale = rescale_priors),
+    priors_heterogeneity       = set_default_priors("heterogeneity", rescale = rescale_priors),
+    priors_bias                = set_default_priors("bias",          rescale = rescale_priors),
+    priors_effect_null         = set_default_priors("effect",        null = TRUE),
+    priors_heterogeneity_null  = set_default_priors("heterogeneity", null = TRUE),
+    priors_bias_null           = set_default_priors("bias",          null = TRUE),
+    priors_hierarchical        = set_default_priors("hierarchical"),
+    priors_hierarchical_null   = set_default_priors("hierarchical", null = TRUE),
 
-    prior_covariates       = prior("normal", parameters = list(mean = 0, sd = 0.25)),
-    prior_covariates_null  = prior("spike",  parameters = list(location = 0)),
-    prior_factors          = prior_factor("mnormal", parameters = list(mean = 0, sd = 0.25), contrast = "meandif"),
-    prior_factors_null     = prior_factor("spike",   parameters = list(location = 0), contrast = "meandif"),
+    prior_covariates       = set_default_priors("covariates", rescale = rescale_priors),
+    prior_covariates_null  = set_default_priors("covariates", null = TRUE),
+    prior_factors          = set_default_priors("factors", rescale = rescale_priors),
+    prior_factors_null     = set_default_priors("factors", null = TRUE),
 
     # MCMC fitting settings
-    chains = 3, sample = 5000, burnin = 2000, adapt = 500, thin = 1, parallel = FALSE,
+    algorithm = "bridge", chains = 3, sample = 5000, burnin = 2000, adapt = 500, thin = 1, parallel = FALSE,
     autofit = TRUE, autofit_control = set_autofit_control(), convergence_checks = set_convergence_checks(),
 
     # additional settings
@@ -179,8 +173,6 @@ RoBMA.reg <- function(
     priors_hierarchical_null = priors_hierarchical_null, priors_hierarchical = priors_hierarchical,
     prior_covariates_null = prior_covariates_null, prior_covariates = prior_covariates,
     prior_factors_null = prior_factors_null, prior_factors = prior_factors)
-  object$models     <- .make_models.reg(object[["priors"]], .is_multivariate(object), .is_weighted(object), dots[["do_not_fit"]])
-
 
   ### additional information
   object$add_info <- .check_and_list_add_info(
@@ -191,6 +183,7 @@ RoBMA.reg <- function(
     output_scale           = .transformation_var(prior_scale),
     effect_measure         = attr(object$data[["outcome"]], "effect_measure"),
     effect_direction       = effect_direction,
+    algorithm              = algorithm,
     standardize_predictors = standardize_predictors,
     seed                   = seed,
     save                   = save,
@@ -198,6 +191,14 @@ RoBMA.reg <- function(
     errors                 = NULL
   )
 
+  ### make models
+  if(algorithm == "bridge"){
+    object$models <- .make_models.reg(object[["priors"]], .is_multivariate(object), .is_weighted(object), dots[["do_not_fit"]])
+  }else if(algorithm == "ss"){
+    object$model  <- .make_model_ss.reg(object[["priors"]], .is_multivariate(object), .is_weighted(object), dots[["do_not_fit"]])
+  }
+
+
   # the check requires the 'add_info' object already created
   object$add_info[["warnings"]] <- c(.check_effect_direction(object), .check_predictors_scaling(object))
 
@@ -208,46 +209,59 @@ RoBMA.reg <- function(
 
 
   ### fit the models and compute marginal likelihoods
-  if(!object$fit_control[["parallel"]]){
+  if(algorithm == "bridge"){
 
-    if(dots[["is_JASP"]]){
-      .JASP_progress_bar_start(length(object[["models"]]))
-    }
+    # using the individual models & bridge sampling for model-averaging
+    if(!object$fit_control[["parallel"]]){
 
-    for(i in seq_along(object[["models"]])){
-      object$models[[i]] <- .fit_RoBMA_model(object, i)
+      # sequential model fitting using JAGS & bridge sampling
       if(dots[["is_JASP"]]){
-        .JASP_progress_bar_tick()
+        .JASP_progress_bar_start(length(object[["models"]]))
       }
+
+      for(i in seq_along(object[["models"]])){
+        object$models[[i]] <- .fit_RoBMA_model(object, i)
+        if(dots[["is_JASP"]]){
+          .JASP_progress_bar_tick()
+        }
+      }
+
+    }else{
+
+      # parallel model fitting using JAGS & bridge sampling
+      fitting_order <- .fitting_priority(object[["models"]])
+
+      cl <- parallel::makePSOCKcluster(floor(RoBMA.get_option("max_cores") / object$fit_control[["chains"]]))
+      parallel::clusterEvalQ(cl, {library("RoBMA")})
+      parallel::clusterExport(cl, "object", envir = environment())
+      object$models <- parallel::parLapplyLB(cl, fitting_order, .fit_RoBMA_model, object = object)[order(fitting_order)]
+      parallel::stopCluster(cl)
+
     }
 
-  }else{
+    # create ensemble only if at least one model converged
+    if(any(.get_model_convergence(object))){
 
-    fitting_order <- .fitting_priority(object[["models"]])
+      # balance probability of non-converged models
+      if(object$convergence_checks[["balance_probability"]] && !all(.get_model_convergence(object))){
+        object <- .balance_component_probability(object)
+      }
 
-    cl <- parallel::makePSOCKcluster(floor(RoBMA.get_option("max_cores") / object$fit_control[["chains"]]))
-    parallel::clusterEvalQ(cl, {library("RoBMA")})
-    parallel::clusterExport(cl, "object", envir = environment())
-    object$models <- parallel::parLapplyLB(cl, fitting_order, .fit_RoBMA_model, object = object)[order(fitting_order)]
-    parallel::stopCluster(cl)
-
-  }
-
-
-  # create ensemble only if at least one model converged
-  if(any(.get_model_convergence(object))){
-
-    # balance probability of non-converged models
-    if(object$convergence_checks[["balance_probability"]] && !all(.get_model_convergence(object))){
-      object <- .balance_component_probability(object)
+      ### compute the model-space results
+      object$models        <- BayesTools::models_inference(object[["models"]])
+      object$RoBMA         <- .ensemble_inference(object)
+      object$coefficients  <- .compute_coeficients(object[["RoBMA"]])
     }
 
-    ### compute the model-space results
-    object$models        <- BayesTools::models_inference(object[["models"]])
-    object$RoBMA         <- .ensemble_inference(object)
+
+  }else if(object$add_info[["algorithm"]] == "ss"){
+
+    # model fitting using JAGS with spike and slab priors
+    object$model         <- .fit_RoBMA_model.ss(object)
+    object$RoBMA         <- .as_ensemble_inference(object)
     object$coefficients  <- .compute_coeficients(object[["RoBMA"]])
-  }
 
+  }
 
   ### collect and print errors and warnings
   object$add_info[["errors"]]   <- c(object$add_info[["errors"]],   .get_model_errors(object))
@@ -256,7 +270,7 @@ RoBMA.reg <- function(
 
 
   ### remove model posteriors if asked to
-  if(save == "min"){
+  if(save == "min" && object$add_info[["algorithm"]] == "bridge"){
     object <- .remove_model_posteriors(object)
     object <- .remove_model_margliks(object)
   }
