@@ -19,12 +19,12 @@
   if(!.is_model_constant(priors)){
 
     if(attr(model, "multivariate")){
-      object[["data"]] <- .order_data.mv(object[["data"]], inherits(model, "RoBMA.reg.model"))
+      object[["data"]] <- .order_data.mv(object[["data"]], .is_model_regression(model))
     }
 
 
     # deal with regression vs basic models
-    if(inherits(model, "RoBMA.reg.model")){
+    if(.is_model_regression(model)){
       data_outcome       <- object[["data"]][["outcome"]]
       fit_priors         <- priors[names(priors) != "terms"]
       formula_list       <- .generate_model_formula_list(object[["formula"]])
@@ -44,10 +44,10 @@
       model_syntax <- .generate_model_syntax.mv(
         priors           = fit_priors,
         effect_direction = add_info[["effect_direction"]],
-        priors_scale     = add_info[["prior_scale"]],
+        prior_scale      = add_info[["prior_scale"]],
         effect_measure   = add_info[["effect_measure"]],
         data             = data_outcome,
-        regression       = inherits(model, "RoBMA.reg.model")
+        regression       = .is_model_regression(model)
         )
 
       # remove unnecessary objects from data to mitigate warnings
@@ -63,10 +63,10 @@
       model_syntax <- .generate_model_syntax(
         priors           = fit_priors,
         effect_direction = add_info[["effect_direction"]],
-        priors_scale     = add_info[["prior_scale"]],
+        prior_scale      = add_info[["prior_scale"]],
         effect_measure   = add_info[["effect_measure"]],
         weighted         = attr(model, "weighted"),
-        regression       = inherits(model, "RoBMA.reg.model")
+        regression       = .is_model_regression(model)
       )
 
       # remove unnecessary objects from data to mitigate warnings
@@ -198,7 +198,7 @@
   }else{
 
     # deal with regression vs basic models
-    if(inherits(model, "RoBMA.reg.model")){
+    if(.is_model_regression(model)){
 
       # check that all terms but intercept are spikes at zero
       if(any(sapply(priors[["terms"]][names(priors[["terms"]]) != "intercept"], function(prior) prior$parameters[["location"]] != 0)))
@@ -281,6 +281,168 @@
 
   return(model)
 }
+.fit_RoBMA_model.ss    <- function(object,    extend = FALSE){
+
+  model              <- object[["model"]]
+  priors             <- object[["model"]][["priors"]]
+  fit_control        <- object[["fit_control"]]
+  autofit_control    <- object[["autofit_control"]]
+  convergence_checks <- object[["convergence_checks"]]
+  add_info           <- object[["add_info"]]
+
+  errors   <- NULL
+  warnings <- NULL
+
+  if(attr(model, "multivariate")){
+    stop("Multivariate models are not supported by this function.")
+    # object[["data"]] <- .order_data.mv(object[["data"]], inherits(model, "RoBMA.ss.reg.model"))
+  }
+
+  # deal with regression vs basic models
+  if(.is_model_regression(model)){
+    data_outcome       <- object[["data"]][["outcome"]]
+    fit_priors         <- priors[names(priors) != "terms"]
+    formula_list       <- .generate_model_formula_list(object[["formula"]])
+    formula_data_list  <- .generate_model_formula_data_list(object[["data"]])
+    formula_prior_list <- .generate_model_formula_prior_list(priors)
+  }else if(inherits(model, "RoBMA.model_ss")){
+    data_outcome       <- object[["data"]]
+    fit_priors         <- priors
+    formula_list       <- NULL
+    formula_data_list  <- NULL
+    formula_prior_list <- NULL
+  }
+
+  # deal with multivariate vs univariate models
+  if(attr(model, "multivariate")){
+    # generate the model syntax
+    model_syntax <- .generate_model_syntax.mv(
+      priors           = fit_priors,
+      effect_direction = add_info[["effect_direction"]],
+      prior_scale      = add_info[["prior_scale"]],
+      effect_measure   = add_info[["effect_measure"]],
+      data             = data_outcome,
+      regression       = .is_model_regression(model)
+    )
+
+    # remove unnecessary objects from data to mitigate warnings
+    fit_data     <- .fit_data.mv(
+      data             = data_outcome,
+      priors           = fit_priors,
+      effect_direction = add_info[["effect_direction"]],
+      prior_scale      = add_info[["prior_scale"]]
+    )
+
+  }else{
+    # generate the model syntax
+    model_syntax <- .generate_model_syntax.ss(
+      priors           = priors,
+      effect_direction = add_info[["effect_direction"]],
+      prior_scale      = add_info[["prior_scale"]],
+      effect_measure   = add_info[["effect_measure"]],
+      weighted         = attr(model, "weighted"),
+      regression       = .is_model_regression(model)
+    )
+
+    # remove unnecessary objects from data to mitigate warnings
+    fit_data     <- .fit_data.ss(
+      data             = data_outcome,
+      priors           = priors,
+      effect_direction = add_info[["effect_direction"]],
+      prior_scale      = add_info[["prior_scale"]],
+      weighted         = attr(model, "weighted"),
+      weighted_type    = attr(model, "weighted_type")
+    )
+  }
+
+  # fit the model
+  if(!extend || length(model[["fit"]]) == 0){
+
+    fit <- BayesTools::JAGS_fit(
+      model_syntax          = model_syntax,
+      data                  = fit_data,
+      prior_list            = fit_priors,
+      formula_list          = formula_list,
+      formula_data_list     = formula_data_list,
+      formula_prior_list    = formula_prior_list,
+      chains                = fit_control[["chains"]],
+      adapt                 = fit_control[["adapt"]],
+      burnin                = fit_control[["burnin"]],
+      sample                = fit_control[["sample"]],
+      thin                  = fit_control[["thin"]],
+      autofit               = fit_control[["autofit"]],
+      autofit_control       = autofit_control,
+      parallel              = fit_control[["parallel"]],
+      cores                 = fit_control[["cores"]],
+      silent                = fit_control[["silent"]],
+      seed                  = fit_control[["seed"]],
+      required_packages     = "RoBMA"
+    )
+
+  }else{
+
+    fit <- BayesTools::JAGS_extend(
+      fit                = model[["fit"]],
+      autofit_control    = autofit_control,
+      parallel           = fit_control[["parallel"]],
+      cores              = fit_control[["cores"]],
+      silent             = fit_control[["silent"]],
+      seed               = fit_control[["seed"]]
+    )
+
+  }
+
+
+  # assess the model fit and deal with errors
+  if(inherits(fit, "error")){
+
+    if(grepl("Unknown function", fit$message))
+      stop("The RoBMA module could not be loaded. Check whether the RoBMA package was installed correctly and whether 'RoBMA::RoBMA.private$module_location' contains path to the RoBMA JAGS module.")
+
+    fit                     <- list()
+    attr(fit, "prior_list") <- fit_priors
+
+    converged      <- FALSE
+    has_posterior  <- FALSE
+    errors         <- c(errors, fit$message)
+
+    # deal with failed models
+    marglik        <- list()
+    marglik$logml  <- NA
+    class(marglik) <- "bridge"
+
+  }else{
+
+    has_posterior <- TRUE
+    check_fit     <- BayesTools::JAGS_check_convergence(
+      fit          = fit,
+      prior_list   = attr(fit, "prior_list"),
+      max_Rhat     = convergence_checks[["max_Rhat"]],
+      min_ESS      = convergence_checks[["min_ESS"]],
+      max_error    = convergence_checks[["max_error"]],
+      max_SD_error = convergence_checks[["max_SD_error"]]
+    )
+    warnings    <- c(warnings, attr(fit, "warnings"), attr(check_fit, "errors"))
+    if(convergence_checks[["remove_failed"]] && !check_fit){
+      converged <- FALSE
+    }else{
+      converged <- TRUE
+    }
+
+  }
+
+
+  # add results
+  model$fit           <- fit
+  model$errors        <- errors
+  model$warnings      <- warnings
+  model$converged     <- converged
+  model$has_posterior <- has_posterior
+  model$output_scale  <- add_info[["prior_scale"]]
+  model$prior_scale   <- add_info[["prior_scale"]]
+
+  return(model)
+}
 .fit_BiBMA_model       <- function(object, i, extend = FALSE){
 
   model              <- object[["models"]][[i]]
@@ -448,7 +610,7 @@
     fit_summaries <- .runjags_summary_list(
       fit               = fit,
       priors            = attr(fit, "prior_list"),
-      priors_scale      = add_info[["prior_scale"]],
+      prior_scale       = add_info[["prior_scale"]],
       warnings          = warnings,
       remove_parameters = c("pi", if(attr(model, "random")) "gamma")
     )
@@ -571,6 +733,54 @@
 
   return(fit_data)
 }
+.fit_data.ss              <- function(data, priors, effect_direction, prior_scale, weighted, weighted_type){
+
+  # unlist the data.frame
+  original_measure <- attr(data, "original_measure")
+  effect_measure   <- attr(data, "effect_measure")
+
+  fit_data <- list()
+  # change the effect size direction (important for one-sided selection and PET/PEESE)
+  if(effect_direction == "negative"){
+    fit_data$y <- - data[,"y"]
+  }else{
+    fit_data$y <- data[,"y"]
+  }
+  fit_data$se <- data[,"se"]
+  fit_data$K  <- length(data[["y"]])
+
+  # add weights proportional to the number of estimates from a study
+  if(weighted){
+    fit_data$weight <- .get_id_weights(data, weighted_type)
+  }
+
+  if(any(sapply(priors[["bias"]], is.prior.weightfunction))){
+
+    # create the weightfunction mapping for effect size thresholds
+    steps  <- BayesTools::weightfunctions_mapping(priors[["bias"]][sapply(priors[["bias"]], is.prior.weightfunction)], cuts_only = TRUE, one_sided = TRUE)
+    steps  <- rev(steps)[c(-1, -length(steps))]
+    crit_y <- .get_cutoffs(fit_data[["y"]], fit_data[["se"]], list(distribution = "one.sided", parameters = list(steps = steps)), original_measure, effect_measure)
+
+    # create the weightfunction mapping to weights (transform all weight functions to one-sided)
+    crit_y_mapping <- matrix(0, nrow = length(priors[["bias"]]), ncol = ncol(crit_y))
+    crit_y_mapping_max <- rep(0, length(priors[["bias"]]))
+    for(i in seq_along(priors[["bias"]])){
+      if(is.prior.weightfunction(priors[["bias"]][[i]])){
+        ### the following subsetting allows us "merge" steps with equal weights due to the construction
+        # specify indexes of the relevant steps
+        this_steps <- .get_one_sided_cuts(priors[["bias"]][[i]])
+        crit_y_mapping[i,1:length(this_steps)] <- which(steps %in% this_steps)
+        crit_y_mapping_max[i] <- length(this_steps)
+      }
+    }
+
+    fit_data$crit_y             <- t(crit_y)
+    fit_data$crit_y_mapping     <- t(crit_y_mapping)
+    fit_data$crit_y_mapping_max <- crit_y_mapping_max
+  }
+
+  return(fit_data)
+}
 .order_data.mv            <- function(data, regression){
   # prepares data in a better order for the subsequent vectorization of multivariate distributions
 
@@ -595,7 +805,7 @@
 
   return(data)
 }
-.generate_model_syntax    <- function(priors, effect_direction, priors_scale, effect_measure, weighted, regression){
+.generate_model_syntax    <- function(priors, effect_direction, prior_scale, effect_measure, weighted, regression){
 
   model_syntax <- "model{\n"
 
@@ -605,18 +815,18 @@
   # deal with mu as a vector or scalar based on whether it is regression or not
   if(regression){
     model_syntax <- paste0(model_syntax, "for(i in 1:K){\n")
-    model_syntax <- paste0(model_syntax, .JAGS_scale(priors_scale, effect_measure, "mu[i]",  "mu_transformed[i]"))
+    model_syntax <- paste0(model_syntax, .JAGS_scale(prior_scale, effect_measure, "mu[i]",  "mu_transformed[i]"))
     model_syntax <- paste0(model_syntax, "}\n")
   }else{
-    model_syntax <- paste0(model_syntax, .JAGS_scale(priors_scale, effect_measure, "mu",  "mu_transformed"))
+    model_syntax <- paste0(model_syntax, .JAGS_scale(prior_scale, effect_measure, "mu",  "mu_transformed"))
   }
 
-  model_syntax <- paste0(model_syntax, .JAGS_scale(priors_scale, effect_measure, "tau", "tau_transformed"))
+  model_syntax <- paste0(model_syntax, .JAGS_scale(prior_scale, effect_measure, "tau", "tau_transformed"))
   if(!is.null(priors[["PET"]])){
     model_syntax <- paste0(model_syntax, paste0("PET_transformed = PET\n"))
   }else if(!is.null(priors[["PEESE"]])){
     # don't forget that the transformation is inverse for PEESE
-    model_syntax <- paste0(model_syntax, .JAGS_scale(effect_measure, priors_scale, "PEESE", "PEESE_transformed"))
+    model_syntax <- paste0(model_syntax, .JAGS_scale(effect_measure, prior_scale, "PEESE", "PEESE_transformed"))
   }
 
 
@@ -664,7 +874,7 @@
 
   return(model_syntax)
 }
-.generate_model_syntax.mv <- function(priors, effect_direction, priors_scale, effect_measure, data, regression){
+.generate_model_syntax.mv <- function(priors, effect_direction, prior_scale, effect_measure, data, regression){
 
   model_syntax <- "model{\n"
 
@@ -674,18 +884,18 @@
   # deal with mu as a vector or scalar based on whether it is regression or not
   if(regression){
     model_syntax <- paste0(model_syntax, "for(i in 1:(K+K_v)){\n")
-    model_syntax <- paste0(model_syntax, .JAGS_scale(priors_scale, effect_measure, "mu[i]",  "mu_transformed[i]"))
+    model_syntax <- paste0(model_syntax, .JAGS_scale(prior_scale, effect_measure, "mu[i]",  "mu_transformed[i]"))
     model_syntax <- paste0(model_syntax, "}\n")
   }else{
-    model_syntax <- paste0(model_syntax, .JAGS_scale(priors_scale, effect_measure, "mu",  "mu_transformed"))
+    model_syntax <- paste0(model_syntax, .JAGS_scale(prior_scale, effect_measure, "mu",  "mu_transformed"))
   }
-  model_syntax <- paste0(model_syntax, .JAGS_scale(priors_scale, effect_measure, "tau", "tau_transformed"))
+  model_syntax <- paste0(model_syntax, .JAGS_scale(prior_scale, effect_measure, "tau", "tau_transformed"))
 
   if(!is.null(priors[["PET"]])){
     model_syntax <- paste0(model_syntax, paste0("PET_transformed = PET\n"))
   }else if(!is.null(priors[["PEESE"]])){
     # don't forget that the transformation is inverse for PEESE
-    model_syntax <- paste0(model_syntax, .JAGS_scale(effect_measure, priors_scale, "PEESE", "PEESE_transformed"))
+    model_syntax <- paste0(model_syntax, .JAGS_scale(effect_measure, prior_scale, "PEESE", "PEESE_transformed"))
   }
 
 
@@ -796,6 +1006,96 @@
 
   return(model_syntax)
 }
+.generate_model_syntax.ss <- function(priors, effect_direction, prior_scale, effect_measure, weighted, regression){
+
+  ### extract prior information
+  if(is.prior.mixture(priors[["bias"]])){
+    is_PET            <- sapply(priors[["bias"]], is.prior.PET)
+    is_PEESE          <- sapply(priors[["bias"]], is.prior.PEESE)
+    is_weightfunction <- sapply(priors[["bias"]], is.prior.weightfunction)
+  }else{
+    is_PET            <- is.prior.PET(priors[["bias"]])
+    is_PEESE          <- is.prior.PEESE(priors[["bias"]])
+    is_weightfunction <- is.prior.weightfunction(priors[["bias"]])
+  }
+
+
+  # create the model syntax
+  model_syntax <- "model{\n"
+
+  ### prior transformations
+  # the precise transformation for heterogeneity is not used due the inability to re-scale large variances
+  # instead, approximate linear scaling is employed in the same way as in metaBMA package
+  # deal with mu as a vector or scalar based on whether it is regression or not
+  if(regression){
+    model_syntax <- paste0(model_syntax, "for(i in 1:K){\n")
+    model_syntax <- paste0(model_syntax, .JAGS_scale(prior_scale, effect_measure, "mu[i]",  "mu_transformed[i]"))
+    model_syntax <- paste0(model_syntax, "}\n")
+  }else{
+    model_syntax <- paste0(model_syntax, .JAGS_scale(prior_scale, effect_measure, "mu",  "mu_transformed"))
+  }
+
+  model_syntax <- paste0(model_syntax, .JAGS_scale(prior_scale, effect_measure, "tau", "tau_transformed"))
+  if(any(is_PET)){
+    model_syntax <- paste0(model_syntax, paste0("PET_transformed = PET\n"))
+  }
+  if(any(is_PEESE)){
+    # don't forget that the transformation is inverse for PEESE
+    model_syntax <- paste0(model_syntax, .JAGS_scale(effect_measure, prior_scale, "PEESE", "PEESE_transformed"))
+  }
+
+  # marginalized random effects and the effect size
+  prec <- "1 / ( pow(se[i],2) + pow(tau_transformed,2) )"
+
+  # deal with mu as a vector or scalar based on whether it is regression or not
+  if(regression){
+    eff <- ifelse(effect_direction == "negative", "-1 * mu_transformed[i]", "mu_transformed[i]")
+  }else{
+    eff <- ifelse(effect_direction == "negative", "-1 * mu_transformed", "mu_transformed")
+  }
+
+  # TODO: add hierarchical
+
+  ### model
+  model_syntax <- paste0(model_syntax, "\nfor(i in 1:K){\n")
+
+  # marginalized random effects and the effect size
+  tau2 <- "( pow(se[i],2) + pow(tau_transformed,2) )"
+
+  # deal with mu as a vector or scalar based on whether it is regression or not
+  if(regression){
+    eff <- ifelse(effect_direction == "negative", "-1 * mu_transformed[i]", "mu_transformed[i]")
+  }else{
+    eff <- ifelse(effect_direction == "negative", "-1 * mu_transformed", "mu_transformed")
+  }
+
+  # add PET/PEESE
+  if(any(is_PET)){
+    eff <- paste0(eff, " + PET_transformed * se[i]")
+  }
+  if(any(is_PEESE)){
+    eff <- paste0(eff, " + PEESE_transformed * pow(se[i],2)")
+  }
+
+  if(any(is_weightfunction)){
+    if(weighted){
+      model_syntax <- paste0(model_syntax, "  y[i] ~ dwwnorm_mix(", eff, ",", "sqrt", tau2, ", crit_y[,i], omega, crit_y_mapping[,bias_indicator], crit_y_mapping_max[bias_indicator], weight[i])\n")
+    }else{
+      model_syntax <- paste0(model_syntax, "  y[i] ~ dwnorm_mix(", eff, ",", "sqrt", tau2, ", crit_y[,i], omega, crit_y_mapping[,bias_indicator], crit_y_mapping_max[bias_indicator])\n")
+    }
+  }else{
+    if(weighted){
+      model_syntax <- paste0(model_syntax, "  y[i] ~ dwnorm(", eff, ",", "1/", tau2, ", weight[i])\n")
+    }else{
+      model_syntax <- paste0(model_syntax, "  y[i] ~ dnorm(",  eff, ",", "1/", tau2, ")\n")
+    }
+  }
+
+  model_syntax <- paste0(model_syntax, "}\n")
+  model_syntax <- paste0(model_syntax, "}")
+
+  return(model_syntax)
+}
 .marglik_function         <- function(parameters, data, priors, effect_direction, prior_scale, effect_measure){
 
   # extract parameters
@@ -1014,7 +1314,7 @@
       if(is.prior.simple(model$priors[["mu"]])){
         difficulty <- difficulty + 1
       }
-    }else if(inherits(model, "RoBMA.reg.model") | inherits(model, "BiBMA.reg.model")){
+    }else if(.is_model_regression(model) | inherits(model, "BiBMA.reg.model")){
       difficulty <-  difficulty + sum(sapply(model$priors[["terms"]], function(prior){
         if(is.prior.point(prior)){
           return(0)
@@ -1039,36 +1339,42 @@
 
   return(order(fitting_difficulty, decreasing = TRUE))
 }
-.runjags_summary_list   <- function(fit, priors, priors_scale, warnings, remove_parameters = NULL){
+.runjags_summary_list   <- function(fit, priors, prior_scale, warnings, remove_parameters = NULL, measures = c("d", "r", "z", "logOR", "OR"), transformations_only = FALSE){
 
   summary_list <- list()
 
-  for(measure in c("d", "r", "z", "logOR", "OR")){
+  for(measure in measures){
 
     # prepare transformations if necessary
-    if(measure != priors_scale){
+    if(measure != prior_scale){
       transformations <- list()
+      # effect size transformation
       if("mu" %in% names(priors) && ((is.prior.point(priors[["mu"]]) && priors[["mu"]][["parameters"]][["location"]] != 0) || !is.prior.point(priors[["mu"]]))){
-        transformations[["mu"]] <- .get_transform_mu(priors_scale, measure, fun = FALSE)
+        transformations[["mu"]] <- .get_transform_mu(prior_scale, measure, fun = FALSE)
       }
-      for(i in seq_along(priors[!names(priors) %in% c("mu", "tau", "omega", "PET", "PEESE")])){
-        transformations[[names(priors[!names(priors) %in% c("mu", "tau", "omega", "PET", "PEESE")])[i]]] <- .get_transform_mu(priors_scale, measure, fun = FALSE)
+      # meta-regression transformations
+      for(i in seq_along(priors[!names(priors) %in% c("mu", "tau", "omega", "PET", "PEESE", "bias")])){
+        transformations[[names(priors[!names(priors) %in% c("mu", "tau", "omega", "PET", "PEESE")])[i]]] <- .get_transform_mu(prior_scale, measure, fun = FALSE)
       }
-      for(i in seq_along(priors[!names(priors) %in% c("mu", "tau", "omega", "PET", "PEESE")])){
-        transformations[[names(priors[!names(priors) %in% c("mu", "tau", "omega", "PET", "PEESE")])[i]]] <- list(
-          "fun" = .transform_mu,
-          "arg" = list(
-            "from" = priors_scale,
-            "to"   = measure
-          )
-        )
+      # TODO: delete
+      # for(i in seq_along(priors[!names(priors) %in% c("mu", "tau", "omega", "PET", "PEESE")])){
+      #   transformations[[names(priors[!names(priors) %in% c("mu", "tau", "omega", "PET", "PEESE")])[i]]] <- list(
+      #     "fun" = .transform_mu,
+      #     "arg" = list(
+      #       "from" = prior_scale,
+      #       "to"   = measure
+      #     )
+      #   )
+      # }
+
+      # heterogeneity transformation
+      if("tau" %in% names(priors) && ((is.prior.point(priors[["tau"]]) && priors[["tau"]][["parameters"]][["location"]] != 0) || !is.prior.point(priors[["tau"]]))){
+        transformations[["tau"]] <- .get_scale(prior_scale, measure, fun = FALSE)
       }
-      if("tau" %in% names(priors) && ((is.prior.point(priors[["mu"]]) && priors[["mu"]][["parameters"]][["location"]] != 0) || !is.prior.point(priors[["tau"]]))){
-        transformations[["tau"]] <- .get_scale(priors_scale, measure, fun = FALSE)
-      }
-      if("PEESE" %in% names(priors)){
+      # PEESE transformation (PET is invariant)
+      if("PEESE" %in% names(priors) || (!is.null(priors[["bias"]]) && any(sapply(priors[["bias"]], is.prior.PEESE)))){
         # the transformation is inverse for PEESE
-        transformations[["PEESE"]] <- .get_scale(measure, priors_scale, fun = FALSE)
+        transformations[["PEESE"]] <- .get_scale(measure, prior_scale, fun = FALSE)
       }
       if(length(transformations) == 0){
         transformations <- NULL
@@ -1077,13 +1383,20 @@
       transformations <- NULL
     }
 
+    if(transformations_only){
+      if(length(measures) > 1)
+        stop("Only one measure can be transformed at a time.")
+      return(transformations)
+    }
+
     summary_list[[measure]] <- suppressMessages(BayesTools::runjags_estimates_table(
       fit               = fit,
       transformations   = transformations,
       transform_factors = TRUE,
       formula_prefix    = FALSE,
+      remove_inclusion  = TRUE,
       warnings          = warnings,
-      footnotes         = .scale_note(priors_scale, measure),
+      footnotes         = .scale_note(prior_scale, measure),
       remove_parameters = remove_parameters
     ))
   }
@@ -1129,6 +1442,9 @@
 
   return(priors)
 }
+.is_model_regression    <- function(model){
+  return(inherits(model, "RoBMA.reg.model") || inherits(model, "RoBMA.reg.model_ss") || inherits(model, "BiBMA.reg.model"))
+}
 
 .generate_model_formula_list       <- function(formula){
 
